"""
Store provenance in json files
"""
import json

from .provenance import fmt_prov


def json_dump(data, pth, pth_script, **kwds):
    """Write data in json file.

    Args:
        data (dict): data to write
        pth (str|Path): path to file to write
        pth_script (str|Path): path to script that generated data
        **kwds: additional arguments that will be passed to dump

    Returns:
        None
    """
    data["_comment"] = f"This file has been generated by: {fmt_prov(pth_script)}"
    json.dump(data, open(pth, "w"), **kwds)
    del data["_comment"]


def json_prov(data):
    """Read provenan.

    Args:
        data (dict): data read from json file saved with json_dump

    Returns:
        (str): provenance, path to script that generated data
    """
    return data['_comment'].split(":")[-1].strip()
